<?php

require_once('environ.php');

function url_style($file) {
    return STYLE_DIR . '/' . $file;
}

function url_script($file) {
    return SCRIPT_DIR . '/' . $file;
}

function url_asset($file) {
    return ASSETS_DIR . '/' . $file;
}

function url_image($file) {
    return IMAGES_DIR . '/' . $file;
}

function url_doc($file) {
    return DOCS_DIR . '/' . $file;
}

function url_file($file) {
    return FILES_DIR . '/' . $file;
}

function url_download($file) {
    return DOWNLOAD_DIR . '/' . $file;
}

class ExceptionRoot extends Exception {
    protected $details;
    protected $severity;

    public function __construct($message, $code = 0, $details = NULL) {
        parent::__construct($message, $code);
        $this->details = $details;
    }

    public function __toString() {
        if ($this->details)
            return sprintf('<b>%s</b><dl><dt>Szczegy<dd>%s</dl>',
                $this->getMessage(), $this->getDetails());
        else
            return sprintf('<b>%s</b>', $this->getMessage());
    }

    public function getDetails() {
        return $this->details;
    }

    public function getSeverity() {
        switch ($this->severity) {
            case E_ERROR:
                return 'ERROR';
            case E_WARNING:
                return 'WARNING';
            case E_PARSE:
                return 'PARSE';
            case E_NOTICE:
                return 'NOTICE';
            case E_CORE_ERROR:
                return 'CORE_ERROR';
            case E_CORE_WARNING:
                return 'CORE_WARNING';
            case E_COMPILE_ERROR:
                return 'COMPILE_ERROR';
            case E_COMPILE_WARNING:
                return 'COMPILE_WARNING';
            case E_USER_ERROR:
                return 'USER_ERROR';
            case E_USER_WARNING:
                return 'USER_WARNING';
            case E_USER_NOTICE:
                return 'USER_NOTICE';
            case E_ALL:
                return 'ALL';
            case E_STRICT:
                return 'STRICT';
            case E_RECOVERABLE_ERROR:
                return 'RECOVERABLE_ERROR';
        }
    }
}

class ExceptionError extends ExceptionRoot {
    protected $context;

    public function __construct($message, $code, $severity, $file, $line, $context) {
        parent::__construct($message, $code);
        $this->severity = $severity;
        $this->file = $file;
        $this->line = $line;
        $this->context = $context;
    }

    public function __toString() {
        return sprintf('<b>%s</b><dl><dt>%s<dt>Plik<dd>%s<dt>Linia<dd>%d</dl>',
                $this->getMessage(), $this->getSeverity(), $this->getFile(), $this->getLine());
    }

    public function getContext() {
        return $this->context;
    }
}

function exception_error_handler($errno, $errstr, $errfile, $errline, $errcontext) {
    throw new ExceptionError($errstr, 0, $errno, $errfile, $errline, $errcontext);
}

//set_error_handler("exception_error_handler", E_ALL);

function array_first(array $array) {
    return reset($array);
}

function array_flatten(array $array) {
    $result = array();

    foreach ($array as $item) {
        if (is_object($item))
            $result[] = $item;
        elseif (is_array($item))
            $result = array_merge($result, array_flatten($item));
        else
            $result[] = $item;
    }

    return $result;
}

function array_key_by_value() {
    $data = array_flatten(func_get_args());
    return array_combine($data, $data);
}

function array_replace_inner(array $array1, array $array2) {
    foreach ($array1 as $key => $value)
        if (array_key_exists($key, $array2)) $result[$key] = $array2[$key];
    return $result;
}

function array_replace_left(array $array1, array $array2) {
    foreach ($array1 as $key => $value)
        $result[$key] = array_key_exists($key, $array2) ? $array2[$key] : NULL;
    return $result;
}

function array_to_query(array $data) {
    $query = array();
    foreach ($data as $key => $value)
        $query[] = $key . '=' . $value;
    return implode('&', $query);
}

function get_get_data($key, $default = NULL) {
    if (array_key_exists($key, $_GET))
        return $_GET[$key];
    else
        return $default;
}

function get_post_data($key, $default = NULL) {
    if (array_key_exists($key, $_POST))
        return $_POST[$key];
    else
        return $default;
}

function get_request_data($key, $default = NULL) {
    if (array_key_exists($key, $_REQUEST))
        return $_REQUEST[$key];
    else
        return $default;
}

function is_integer_str($value) {
    return is_numeric($value) && (string)(integer)$value === (string)$value;
}

function is_float_str($value) {
    return is_numeric($value) && (string)(double)$value == (string)$value;
}

function are_equal($a, $b) {
    if (is_numeric($a) && is_numeric($b))
        return $a == $b;
    else
        return (string)$a == (string)$b;
}

function tempfile($path, $prefix = NULL, $suffix = NULL) {
    do {
        $filename = $path . '/' . $prefix . mt_rand(1000, 9999) . $suffix;
        $fd = @fopen($filename, 'x');
    } while(! $fd);

    fclose($fd);
    return $filename;
}

function tempdir($path, $prefix = NULL, $suffix = NULL) {
    do {
        $dirname = $path . '/' . $prefix . mt_rand(1000, 9999) . $suffix;
    } while(! mkdir($dirname, 0700));

    return $dirname;
}

function get_microtime() {
    list($utime, $time) = explode(' ', microtime());
    return ((float)$utime + (float)$time);
}

function q_encode($input, $charset = 'ISO-8859-2') {
    preg_match_all('/(\\w*[\\x80-\\xFF]+\\w*)/', $input, $matches);
    foreach ($matches[1] as $value) {
        $replacement = preg_replace_callback('/([\\x80-\\xFF])/', 
                function ($matches) { return '=' . strtoupper(dechex(ord($matches[0]))); }, $value);
        $input = str_replace($value, '=?' . $charset . '?Q?' . $replacement . '?=', $input);
    }
    return $input;
}

function win2iso($str) {
    $search = array(chr(0xa5), chr(0xc6), chr(0xca), chr(0xa3), chr(0xd1), chr(0xd3), chr(0x8c), chr(0x8f), chr(0xaf), chr(0xb9), chr(0xe6), chr(0xea), chr(0xb3), chr(0xf1), chr(0xf3), chr(0x9c), chr(0x9f), chr(0xbf));
    $replace = array(chr(0xa1), chr(0xc6), chr(0xca), chr(0xa3), chr(0xd1), chr(0xd3), chr(0xa6), chr(0xac), chr(0xaf), chr(0xb1), chr(0xe6), chr(0xea), chr(0xb3), chr(0xf1), chr(0xf3), chr(0xb6), chr(0xbc), chr(0xbf));
    return str_replace($search, $replace, $str);
}

function iso2win($str) {
    $search = array(chr(0xa1), chr(0xc6), chr(0xca), chr(0xa3), chr(0xd1), chr(0xd3), chr(0xa6), chr(0xac), chr(0xaf), chr(0xb1), chr(0xe6), chr(0xea), chr(0xb3), chr(0xf1), chr(0xf3), chr(0xb6), chr(0xbc), chr(0xbf));
    $replace = array(chr(0xa5), chr(0xc6), chr(0xca), chr(0xa3), chr(0xd1), chr(0xd3), chr(0x8c), chr(0x8f), chr(0xaf), chr(0xb9), chr(0xe6), chr(0xea), chr(0xb3), chr(0xf1), chr(0xf3), chr(0x9c), chr(0x9f), chr(0xbf));
    return str_replace($search, $replace, $str);
}

function utf2iso($text) {
   return iconv('UTF-8', 'ISO-8859-2', $text);
}

function iso2utf($text) {
   return iconv('ISO-8859-2', 'UTF-8', $text);
}

function win_cleanup($str) {
    $search = array(
            chr(0x80), chr(0x81), chr(0x82), chr(0x83), chr(0x84), chr(0x85), chr(0x86), chr(0x87), chr(0x88), chr(0x89), chr(0x8b),
            chr(0x90), chr(0x91), chr(0x92), chr(0x93), chr(0x94), chr(0x95), chr(0x96), chr(0x97), chr(0x98), chr(0x99), chr(0x9b),
            chr(0xa6), chr(0xa9), chr(0xab), chr(0xac), chr(0xae), 
            chr(0xb1), chr(0xb5), chr(0xb6), chr(0xb7), chr(0xbb));
    $replace = array(
            chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20),
            chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20),
            chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20), 
            chr(0x20), chr(0x20), chr(0x20), chr(0x20), chr(0x20));
    return str_replace($search, $replace, $str);
}

function iso_cleanup($str) {
    $search = array(chr(0xa1), chr(0xc6), chr(0xca), chr(0xa3), chr(0xd1), chr(0xd3), chr(0xa6), chr(0xac), chr(0xaf), chr(0xb1), chr(0xe6), chr(0xea), chr(0xb3), chr(0xf1), chr(0xf3), chr(0xb6), chr(0xbc), chr(0xbf));
    $replace = array('');
    return str_replace($search, $replace, $str);
}

?>
